@@ -83,6 +83,7 @@ c
 c
 #include  "Zglobalc.h"
 #include  "Ztrack.h"  
+#include  "Ztrackp.h"
 #include  "Zobs.h"  
 #include  "Zobsv.h"  
 #include  "Zincidentp.h"
@@ -140,6 +141,15 @@ c     @@@@@@@@@@@@@@@
          call rndc(ux)
       enddo   
 c     @@@@@@@@@@@@@@@
+c                uv 5.51
+      if(Reverse .ne. 0) then
+c          we must revert the angle
+         dir2.r(1) = -dir2.r(1)
+         dir2.r(2) = -dir2.r(2)
+         dir2.r(3) = -dir2.r(3)
+         call ctransVectZ(dir1, dir2, incident.vec.w)
+      endif
+
 c         reset others  
       call cresetPrim2(incident)
       end
